(experimental)
miscalibration_test(x, ...)
# S3 method for reliabilitydiag
miscalibration_test(x, ...)
# S3 method for numeric
miscalibration_test(x, y, ...)an R object inheriting from 'reliabilitydiag' or a numeric
vector of probability predictions taking values in [0, 1].
further arguments to be passed to or from methods.
a numeric vector of binary response values in {0, 1} to be predicted.
returns a 'tibble' with entries
forecast | the name of the prediction method. |
miscalibration | the miscalibration statistic
(see summary.reliabilitydiag). |
pvalue | the pvalue. |