Printing methods for 'reliabilitydiag' and
'summary.reliabilitydiag' objects.
an object inheriting from the class 'reliabilitydiag'.
further arguments to be passed to or from methods;
in particular, these are passed to autoplot.reliabilitydiag
and print.tbl_df.
Invisibly returns x.
print.reliabilitydiag always sends a plot to the current graphics
device and prints a summary to the console.
print.summary.reliabilitydiag prints the summary output to the console.